@@ -3,6 +3,7 @@ use std::{fmt::Display, ops::{Add, Mul}, ops::Sub};
 /// A vector3 representation that can be used with natives.
 /// 
 /// To make it compatible with natives every field is 8 byte aligned.
+#[must_use]
 #[repr(C, align(1))]
 #[derive(Clone, Copy, Debug)]
 pub struct Vector3 {
@@ -16,6 +17,7 @@ pub struct Vector3 {
 
 impl Vector3 {
   /// Creates a new Vector3.
+  #[inline]
   pub fn new(x: f32, y: f32, z: f32) -> Self {
     Self {
       x,
@@ -28,6 +30,7 @@ impl Vector3 {
   }
   
   /// Creates a new Vector3 initialized with 0.
+  #[inline]
   pub fn zero() -> Self {
     Self::new(0f32, 0f32, 0f32)
   }
@@ -53,11 +56,13 @@ impl Vector3 {
   }
   
   /// Gets the distance to another vector.
+  #[inline]
   pub fn distance_to(&self, to: &Vector3) -> f32 {
     (*to - *self).length()
   }
   
   /// Gets the distance to another vector ignoring the z coordinate. 
+  #[inline]
   pub fn distance_to_2d(&self, to: &Vector3) -> f32 {
     let mut tmp = *to - *self;
     tmp.z = 0f32;
@@ -65,6 +70,7 @@ impl Vector3 {
   }
   
   /// Gets the dot product with another vector.
+  #[inline]
   pub fn dot(&self, rhs: &Vector3) -> f32 { 
     self.x * rhs.x +
     self.y * rhs.y +
@@ -81,6 +87,7 @@ impl Display for Vector3 {
 impl Add<Vector3> for Vector3 {
   type Output = Vector3;
   
+  #[inline]
   fn add(self, rhs: Vector3) -> Self::Output {
     Vector3::new(
       self.x + rhs.x,
@@ -93,6 +100,7 @@ impl Add<Vector3> for Vector3 {
 impl Sub<Vector3> for Vector3 {
   type Output = Vector3;
   
+  #[inline]
   fn sub(self, rhs: Vector3) -> Self::Output {
     Vector3::new(
       self.x - rhs.x,
@@ -105,6 +113,8 @@ impl Sub<Vector3> for Vector3 {
 impl Mul<f32> for Vector3 {
   type Output = Vector3;
   
+  #[inline]
+  #[must_use]
   fn mul(self, rhs: f32) -> Self::Output {
     Vector3::new(
       self.x * rhs,
@@ -115,6 +125,7 @@ impl Mul<f32> for Vector3 {
 }
 
 impl PartialEq<Vector3> for Vector3 {
+  #[inline]
   fn eq(&self, other: &Vector3) -> bool {
     self.x == other.x && 
     self.y == other.y && 
@@ -123,6 +134,7 @@ impl PartialEq<Vector3> for Vector3 {
 }
 
 impl PartialOrd<Vector3> for Vector3 {
+  #[inline]
   fn partial_cmp(&self, other: &Vector3) -> Option<std::cmp::Ordering> {
     match self.x.partial_cmp(&other.x) {
       Some(core::cmp::Ordering::Equal) => {}
